<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">
    <xsl:output indent="yes" method="xml"/>
    
    <!-- Typ transformacji 'Dochody'/'Wydatki' -->
    <xsl:variable name="typDokumentu" select="'Wydatki'"></xsl:variable>   
    
    <!-- Root -->
    <xsl:template match="/">
        <!-- Nazwa pliku wynikowego -->       
        <!--<xsl:result-document href="{concat('REKORD',$typDokumentu,'.xml')}"> -->
            <xsl:call-template name="Planowanie">
                <xsl:with-param name="przeplyw" select="$typDokumentu"/> 
            </xsl:call-template>
       <!--</xsl:result-document>-->
    </xsl:template>
    
    <xsl:key name="Naglowek" match="/Planowanie/Dokumenty/Plany/Plan/NaglowekPlan" use="NR_U"/>
    
    <xsl:template name="Planowanie">
        <xsl:param name="przeplyw"/>
        <Plan wersja="1.0">
            <xsl:element name="{$przeplyw}">
                <xsl:for-each select="/Planowanie/Dokumenty/Plany/Plan/*[generate-id(.)=generate-id(key('Naglowek',NR_U)[1])]">
                       
                    <xsl:variable name="NaglowekNR_U" select="NR_U"/>
                    
                    <!-- Jeśli są pozycje dla dokumentu -->
                    <xsl:if test="count(/Planowanie/Dokumenty/Plany/Plan[NaglowekPlan/NR_U=$NaglowekNR_U]/Pozycje/*[PRZEPLYW=substring($przeplyw,1,1)])>0">
                        <Dokument  xsl:use-attribute-sets="AtrybutyDokument">
                            <!-- Dla wszystkich pozycji dokumentów o danym numerze i przepływie -->
                             <xsl:for-each select="/Planowanie/Dokumenty/Plany/Plan[NaglowekPlan/NR_U=$NaglowekNR_U]/Pozycje/*[PRZEPLYW=substring($przeplyw,1,1)]">
                                 <Pozycja xsl:use-attribute-sets="AtrybutyPozycja"/>                       
                             </xsl:for-each>            
                        </Dokument>  
                    </xsl:if>
                </xsl:for-each>  
                
            </xsl:element>    
        </Plan>
    </xsl:template>
  
    <xsl:attribute-set name="AtrybutyDokument">   
        <xsl:attribute name="TYP">
            <xsl:choose>
                <xsl:when test="$typDokumentu='Dochody'">1</xsl:when>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$typDokumentu='Wydatki'">2</xsl:when>
            </xsl:choose>
        </xsl:attribute>
        <xsl:attribute name="NR_DOK">
            <xsl:value-of select="NR_U"/>        
        </xsl:attribute>        
        <xsl:attribute name="ROK">
            <xsl:value-of select="ROKB"/>        
        </xsl:attribute> 
        <xsl:attribute name="MC">
            <xsl:value-of select="number(substring(DATA_U,6,2))"/>        
        </xsl:attribute> 
        <xsl:attribute name="DATA_DOK">
            <xsl:value-of select="DATA_U"/>        
        </xsl:attribute> 
        <xsl:attribute name="ROK_BUD">
            <xsl:value-of select="ROKB"/>        
        </xsl:attribute> 
        <xsl:attribute name="ROK_KSIEGOWY">
            <xsl:value-of select="ROKB"/>        
        </xsl:attribute> 
        <xsl:attribute name="MC_KSIEG">
            <xsl:value-of select="number(substring(DATA_U,6,2))"></xsl:value-of>
        </xsl:attribute> 
        <xsl:attribute name="OPIS">
        </xsl:attribute>
    </xsl:attribute-set> 
    
    
    <xsl:attribute-set name="AtrybutyPozycja">
        <xsl:attribute name="Dysponent">
            <xsl:value-of select="ancestor::Plan/NaglowekPlan/KOD_JB"/>       
        </xsl:attribute>
        <xsl:attribute name="SposobFinansowania">
            <xsl:value-of select="KOD_ZR"/> 
        </xsl:attribute>
        <xsl:attribute name="Dzial">
            <xsl:value-of select="DZIAL"/>                            
        </xsl:attribute>
        <xsl:attribute name="Rozdzial">
            <xsl:value-of select="ROZDZIAL"/>                            
        </xsl:attribute>
        <xsl:attribute name="Paragraf">
            <xsl:value-of select="PAR"/>      
            <xsl:value-of select="PAR4"/>                  
        </xsl:attribute>    
        <xsl:attribute name="Pozycja"></xsl:attribute>   
        <xsl:attribute name="Zadanie">
            <xsl:value-of select="KOD_Z"/>                       
        </xsl:attribute> 
        <xsl:attribute name="Data">
            <xsl:value-of select="ancestor::Plan/NaglowekPlan/DATA_U"/>     
        </xsl:attribute> 
        <xsl:attribute name="Lp">
            <xsl:value-of select="position()"></xsl:value-of>
        </xsl:attribute> 
        <xsl:attribute name="Plan">
            <xsl:value-of select="WARTOSC"></xsl:value-of>
        </xsl:attribute> 
    </xsl:attribute-set>
    
</xsl:stylesheet>